.. _masker_report_examples_ref:

.. only:: html

Examples of masker reports
==========================

Nifti masker reports
--------------------

NiftiMasker
^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_06_manipulating_images_plot_nifti_simple.py`

.. raw:: html
   :file: NiftiMasker_unfitted.html

.. raw:: html
   :file: NiftiMasker_fitted.html

NiftiLabelsMasker
^^^^^^^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_06_manipulating_images_plot_nifti_labels_simple.py`

.. raw:: html
   :file: NiftiLabelsMasker_unfitted.html

.. raw:: html
   :file: NiftiLabelsMasker_fitted.html

NiftiMapsMasker
^^^^^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_03_connectivity_plot_probabilistic_atlas_extraction.py`

.. raw:: html
   :file: NiftiMapsMasker_unfitted.html

.. raw:: html
   :file: NiftiMapsMasker_fitted.html

NiftiSpheresMasker
^^^^^^^^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_adhd_dmn.py`

.. raw:: html
   :file: NiftiSpheresMasker_unfitted.html


.. raw:: html
   :file: NiftiSpheresMasker_fitted.html

Surface masker reports
----------------------

SurfaceMasker
^^^^^^^^^^^^^

.. raw:: html
   :file: SurfaceMasker_unfitted.html

.. raw:: html
   :file: SurfaceMasker_fitted.html

SurfaceLabelsMasker
^^^^^^^^^^^^^^^^^^^

.. raw:: html
   :file: SurfaceLabelsMasker_unfitted.html

.. raw:: html
   :file: SurfaceLabelsMasker_fitted.html

SurfaceMapsMasker
^^^^^^^^^^^^^^^^^

.. raw:: html
   :file: SurfaceMapsMasker_unfitted.html

.. raw:: html
   :file: SurfaceMapsMasker_fitted_plotly.html

.. raw:: html
   :file: SurfaceMapsMasker_fitted_matplotlib.html


Masker reports in notebooks
---------------------------

.. warning::

   The reports in this page may appear slightly different
   than they would in a real report.
   If you suspect a bug, double check by running in a local notebook.

`View HERE. <../../_static/notebook_reports_maskers.html>`_
